@@ -18,7 +18,7 @@ XPath queries and seeing their results.
 The GUI tries to provide all the elements that are needed in order to write,
 test and execute XPath queries without too many troubles. It displays the
 Document Object Model (DOM) and the namespaces used. The program registers the
-namespaces automatically and each element is displayed with it's associated
+namespaces automatically and each element is displayed with its associated
 namespaces. All is performed with the idea of being able of running an XPath
 query as soon as possible without having to fight with the document's namespaces
 and by seeing automatically under which namespace each element is.
@@ -29,7 +29,7 @@ The main idea behind this application is to provide a simple way for building
 XPath queries that will be latter integrated in to a program or XSLT
 transformation paths. Therefore, this program goal is to load an XML document
 and to display it as an XML parser sees it. Thus each node element is prefixed
-with it's namespace.
+with its namespace.
 
 =head1 IMPLEMENTATION
 
@@ -74,7 +74,7 @@ use strict;
 use warnings;
 use 5.006;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 # A true value
